@@ -3,7 +3,7 @@ from typing import Any, ClassVar, Generic, List, Optional, TypeVar, Union
 
 from typing_extensions import Self
 
-from pydantic import BaseModel, ConfigDict, Field, create_model, field_validator, model_validator, validator
+from pydantic import BaseModel, ConfigDict, Field, RootModel, create_model, field_validator, model_validator, validator
 from pydantic.dataclasses import dataclass
 
 
@@ -82,6 +82,7 @@ MutationModel.model_validate(model.__dict__)
 
 
 class KwargsNoMutationModel(BaseModel, frozen=True):
+# MYPY: error: Cannot inherit frozen dataclass from a non-frozen one  [misc]
     x: int
 
 
@@ -177,6 +178,7 @@ NotFrozenModel.model_validate(model.__dict__)
 
 
 class KwargsFrozenModel(BaseModel, frozen=True):
+# MYPY: error: Cannot inherit frozen dataclass from a non-frozen one  [misc]
     x: int
 
 
@@ -309,3 +311,11 @@ m = OuterModel()
 if m.my_var is None:
     # In https://github.com/pydantic/pydantic/issues/7399, this was unreachable
     print('not unreachable')
+
+
+class Foo(BaseModel):
+    pass
+
+
+class Bar(Foo, RootModel[int]):
+    pass
