@@ -1,12 +1,23 @@
+import datetime as dt
 import sys
-from typing import Any, Generic, Iterator, List, Set, TypeVar
+from dataclasses import dataclass
+from typing import Any, Callable, Generic, Iterator, List, Optional, Set, TypeVar
 
 import pytest
-from annotated_types import BaseMetadata, GroupedMetadata, Gt, Lt, Predicate
-from pydantic_core import PydanticUndefined, core_schema
+import pytz
+from annotated_types import BaseMetadata, GroupedMetadata, Gt, Lt, Not, Predicate
+from pydantic_core import CoreSchema, PydanticUndefined, core_schema
 from typing_extensions import Annotated
 
-from pydantic import BaseModel, Field, GetCoreSchemaHandler, TypeAdapter, ValidationError
+from pydantic import (
+    BaseModel,
+    BeforeValidator,
+    Field,
+    GetCoreSchemaHandler,
+    PydanticUserError,
+    TypeAdapter,
+    ValidationError,
+)
 from pydantic.errors import PydanticSchemaGenerationError
 from pydantic.fields import PrivateAttr
 from pydantic.functional_validators import AfterValidator
@@ -232,6 +243,18 @@ def test_modify_get_schema_annotated() -> None:
     calls.clear()
 
 
+def test_annotated_alias_at_low_level() -> None:
+    with pytest.warns(
+        UserWarning,
+        match=r'`alias` specification on field "low_level_alias_field" must be set on outermost annotation to take effect.',
+    ):
+
+        class Model(BaseModel):
+            low_level_alias_field: Optional[Annotated[int, Field(alias='field_alias')]] = None
+
+    assert Model(field_alias=1).low_level_alias_field is None
+
+
 def test_get_pydantic_core_schema_source_type() -> None:
     types: Set[Any] = set()
 
@@ -362,6 +385,12 @@ def test_validate_float_inf_nan_python() -> None:
     ]
 
 
+def test_predicate_success_python() -> None:
+    ta = TypeAdapter(Annotated[int, Predicate(lambda x: x > 0)])
+
+    assert ta.validate_python(1) == 1
+
+
 def test_predicate_error_python() -> None:
     ta = TypeAdapter(Annotated[int, Predicate(lambda x: x > 0)])
 
@@ -379,6 +408,23 @@ def test_predicate_error_python() -> None:
     ]
 
 
+def test_not_operation_error_python() -> None:
+    ta = TypeAdapter(Annotated[int, Not(lambda x: x > 5)])
+
+    with pytest.raises(ValidationError) as exc_info:
+        ta.validate_python(6)
+
+    # insert_assert(exc_info.value.errors(include_url=False))
+    assert exc_info.value.errors(include_url=False) == [
+        {
+            'type': 'not_operation_failed',
+            'loc': (),
+            'msg': 'Not of test_not_operation_error_python.<locals>.<lambda> failed',
+            'input': 6,
+        }
+    ]
+
+
 def test_annotated_field_info_not_lost_from_forwardref():
     from pydantic import BaseModel
 
@@ -409,18 +455,20 @@ def test_annotated_private_field_with_default():
     class AnnotatedPrivateFieldModel(BaseModel):
         _foo: Annotated[int, PrivateAttr(default=1)]
         _bar: Annotated[str, 'hello']
+        _baz: 'Annotated[str, PrivateAttr(default=2)]'
 
     model = AnnotatedPrivateFieldModel()
     assert model._foo == 1
+    assert model._baz == 2
 
-    assert model.__pydantic_private__ == {'_foo': 1}
+    assert model.__pydantic_private__ == {'_foo': 1, '_baz': 2}
 
     with pytest.raises(AttributeError):
         assert model._bar
 
     model._bar = 'world'
     assert model._bar == 'world'
-    assert model.__pydantic_private__ == {'_foo': 1, '_bar': 'world'}
+    assert model.__pydantic_private__ == {'_foo': 1, '_bar': 'world', '_baz': 2}
 
     with pytest.raises(AttributeError):
         assert model.bar
@@ -470,3 +518,129 @@ def test_min_length_field_info_not_lost():
             'type': 'string_too_short',
         }
     ]
+
+
+def test_tzinfo_validator_example_pattern() -> None:
+    """Test that tzinfo custom validator pattern works as explained in the examples/validators docs."""
+
+    @dataclass(frozen=True)
+    class MyDatetimeValidator:
+        tz_constraint: Optional[str] = None
+
+        def tz_constraint_validator(
+            self,
+            value: dt.datetime,
+            handler: Callable,  # (1)!
+        ):
+            """Validate tz_constraint and tz_info."""
+            # handle naive datetimes
+            if self.tz_constraint is None:
+                assert value.tzinfo is None, 'tz_constraint is None, but provided value is tz-aware.'
+                return handler(value)
+
+            # validate tz_constraint and tz-aware tzinfo
+            if self.tz_constraint not in pytz.all_timezones:
+                raise PydanticUserError(
+                    f'Invalid tz_constraint: {self.tz_constraint}', code='unevaluable-type-annotation'
+                )
+            result = handler(value)  # (2)!
+            assert self.tz_constraint == str(
+                result.tzinfo
+            ), f'Invalid tzinfo: {str(result.tzinfo)}, expected: {self.tz_constraint}'
+
+            return result
+
+        def __get_pydantic_core_schema__(
+            self,
+            source_type: Any,
+            handler: GetCoreSchemaHandler,
+        ) -> CoreSchema:
+            return core_schema.no_info_wrap_validator_function(
+                self.tz_constraint_validator,
+                handler(source_type),
+            )
+
+    LA = 'America/Los_Angeles'
+
+    # passing naive test
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator()])
+    ta.validate_python(dt.datetime.now())
+
+    # failing naive test
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator()])
+    with pytest.raises(Exception):
+        ta.validate_python(dt.datetime.now(pytz.timezone(LA)))
+
+    # passing tz-aware test
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator(LA)])
+    ta.validate_python(dt.datetime.now(pytz.timezone(LA)))
+
+    # failing bad tz
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator('foo')])
+    with pytest.raises(Exception):
+        ta.validate_python(dt.datetime.now())
+
+    # failing tz-aware test
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator(LA)])
+    with pytest.raises(Exception):
+        ta.validate_python(dt.datetime.now())
+
+
+def test_utcoffset_validator_example_pattern() -> None:
+    """Test that utcoffset custom validator pattern works as explained in the examples/validators docs."""
+
+    @dataclass(frozen=True)
+    class MyDatetimeValidator:
+        lower_bound: int
+        upper_bound: int
+
+        def validate_tz_bounds(self, value: dt.datetime, handler: Callable):
+            """Validate and test bounds"""
+            assert value.utcoffset() is not None, 'UTC offset must exist'
+            assert self.lower_bound <= self.upper_bound, 'Invalid bounds'
+
+            result = handler(value)
+
+            hours_offset = value.utcoffset().total_seconds() / 3600
+            assert self.lower_bound <= hours_offset <= self.upper_bound, 'Value out of bounds'
+
+            return result
+
+        def __get_pydantic_core_schema__(
+            self,
+            source_type: Any,
+            handler: GetCoreSchemaHandler,
+        ) -> CoreSchema:
+            return core_schema.no_info_wrap_validator_function(
+                self.validate_tz_bounds,
+                handler(source_type),
+            )
+
+    LA = 'America/Los_Angeles'
+
+    # test valid bound passing
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator(-10, 10)])
+    ta.validate_python(dt.datetime.now(pytz.timezone(LA)))
+
+    # test valid bound failing - missing TZ
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator(-12, 12)])
+    with pytest.raises(Exception):
+        ta.validate_python(dt.datetime.now())
+
+    # test invalid bound
+    ta = TypeAdapter(Annotated[dt.datetime, MyDatetimeValidator(0, 4)])
+    with pytest.raises(Exception):
+        ta.validate_python(dt.datetime.now(pytz.timezone(LA)))
+
+
+def test_incompatible_metadata_error() -> None:
+    ta = TypeAdapter(Annotated[List[int], Field(pattern='abc')])
+    with pytest.raises(TypeError, match="Unable to apply constraint 'pattern'"):
+        ta.validate_python([1, 2, 3])
+
+
+def test_compatible_metadata_raises_correct_validation_error() -> None:
+    """Using a no-op before validator to ensure that constraint is applied as part of a chain."""
+    ta = TypeAdapter(Annotated[str, BeforeValidator(lambda x: x), Field(pattern='abc')])
+    with pytest.raises(ValidationError, match="String should match pattern 'abc'"):
+        ta.validate_python('def')
