@@ -1,7 +1,9 @@
 import platform
+import re
 from typing import Generic, Optional, Tuple, TypeVar
 
 import pytest
+from typing_extensions import Annotated
 
 from pydantic import (
     BaseModel,
@@ -78,6 +80,38 @@ def test_create_model_multi_inheritance():
     assert FooModel.__orig_bases__ == (BaseModel, Generic_T)
 
 
+def test_create_model_must_not_reset_parent_namespace():
+    # It's important to use the annotation `'namespace'` as this is a particular string that is present
+    # in the parent namespace if you reset the parent namespace in the call to `create_model`.
+
+    AbcModel = create_model('AbcModel', abc=('namespace', None))
+    with pytest.raises(
+        PydanticUserError,
+        match=re.escape(
+            '`AbcModel` is not fully defined; you should define `namespace`, then call `AbcModel.model_rebuild()`.'
+        ),
+    ):
+        AbcModel(abc=1)
+
+    # Rebuild the model now that `namespace` is defined
+    namespace = int  # noqa F841
+    AbcModel.model_rebuild()
+
+    assert AbcModel(abc=1).abc == 1
+
+    with pytest.raises(ValidationError) as exc_info:
+        AbcModel(abc='a')
+    # insert_assert(exc_info.value.errors(include_url=False))
+    assert exc_info.value.errors(include_url=False) == [
+        {
+            'type': 'int_parsing',
+            'loc': ('abc',),
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
+            'input': 'a',
+        }
+    ]
+
+
 def test_invalid_name():
     with pytest.warns(RuntimeWarning):
         model = create_model('FooModel', _foo=(str, ...))
@@ -483,6 +517,34 @@ def test_create_model_non_annotated():
         create_model('FooModel', foo=(str, ...), bar=123)
 
 
+@pytest.mark.parametrize(
+    'annotation_type,field_info',
+    [
+        (bool, Field(alias='foo_bool_alias', description='foo boolean')),
+        (str, Field(alias='foo_str_alis', description='foo string')),
+    ],
+)
+def test_create_model_typing_annotated_field_info(annotation_type, field_info):
+    annotated_foo = Annotated[annotation_type, field_info]
+    model = create_model('FooModel', foo=annotated_foo, bar=(int, 123))
+
+    assert model.model_fields.keys() == {'foo', 'bar'}
+
+    foo = model.model_fields.get('foo')
+
+    assert foo is not None
+    assert foo.annotation == annotation_type
+    assert foo.alias == field_info.alias
+    assert foo.description == field_info.description
+
+
+def test_create_model_expect_field_info_as_metadata_typing():
+    annotated_foo = Annotated[int, 10]
+
+    with pytest.raises(PydanticUserError, match=r'Field definitions should be a Annotated\[<type>, <FieldInfo>\]'):
+        create_model('FooModel', foo=annotated_foo)
+
+
 def test_create_model_tuple():
     model = create_model('FooModel', foo=(Tuple[int, int], (1, 2)))
     assert model().foo == (1, 2)
@@ -495,7 +557,9 @@ def test_create_model_tuple_3():
 
 
 def test_create_model_protected_namespace_default():
-    with pytest.warns(UserWarning, match='Field "model_prefixed_field" has conflict with protected namespace "model_"'):
+    with pytest.warns(
+        UserWarning, match='Field "model_prefixed_field" in Model has conflict with protected namespace "model_"'
+    ):
         create_model('Model', model_prefixed_field=(str, ...))
 
 
@@ -505,7 +569,7 @@ def test_create_model_protected_namespace_real_conflict():
 
 
 def test_create_model_custom_protected_namespace():
-    with pytest.warns(UserWarning, match='Field "test_field" has conflict with protected namespace "test_"'):
+    with pytest.warns(UserWarning, match='Field "test_field" in Model has conflict with protected namespace "test_"'):
         create_model(
             'Model',
             __config__=ConfigDict(protected_namespaces=('test_',)),
@@ -516,7 +580,7 @@ def test_create_model_custom_protected_namespace():
 
 def test_create_model_multiple_protected_namespace():
     with pytest.warns(
-        UserWarning, match='Field "also_protect_field" has conflict with protected namespace "also_protect_"'
+        UserWarning, match='Field "also_protect_field" in Model has conflict with protected namespace "also_protect_"'
     ):
         create_model(
             'Model',
@@ -548,3 +612,32 @@ def test_json_schema_with_inner_models_with_duplicate_names():
         'title': 'a',
         'type': 'object',
     }
+
+
+def test_resolving_forward_refs_across_modules(create_module):
+    module = create_module(
+        # language=Python
+        """\
+from __future__ import annotations
+from dataclasses import dataclass
+from pydantic import BaseModel
+
+class X(BaseModel):
+    pass
+
+@dataclass
+class Y:
+    x: X
+        """
+    )
+    Z = create_model('Z', y=(module.Y, ...))
+    assert Z(y={'x': {}}).y is not None
+
+
+def test_type_field_in_the_same_module():
+    class A:
+        pass
+
+    B = create_model('B', a_cls=(type, A))
+    b = B()
+    assert b.a_cls == A
